%% This script constructs output needed for figure 3.b in the paper
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


savePath    = '.\results';
loadPath    = '.\data';

%% Names of data (in the control variable set) to include in the RHS (LHS) 
%% when doing the regressions

zvariablesToConsider2 = {'CPI_0', 'CPI_1','CPI_2',...
                            'OGAP_0', 'OGAP_1','OGAP_2',...
                                'KPR_0', 'KPR_1','KPR_2',...
                                'ECB_target', 'ECB_path'};                        
                            
ynamesInRegression = {'Target', 'Path'};

%% Load controlVariables as a table

XX = readtable(fullfile(loadPath, 'controlData.csv'));

%% Load the narrative surpruses and diff in media coverage
results     = load(fullfile(savePath, 'narrativeSurpriseSign.mat'));
d_mn        = results.d_mn;
d_nn        = results.d_nn;
eba_dates   = results.eba_dates;

%% Get common dates
XX.Date.Format          = eba_dates.Format;
[commonDates, ia, ib]   = intersect(cellstr(XX.Date), cellstr(eba_dates));

%% Do the loop over windows and DS

% Empty  output
[doubleLassoResults, doubleLassoResults_bic,...
    doubleLassoResults_s1, doubleLassoResults_bic_s1,...
        doubleLassoResults_s2, doubleLassoResults_bic_s2] = deal(cell(numel(daysToLookBack), numel(daysToLookBack)));
c           = XX{ia, zvariablesToConsider2};        
c(isnan(c)) = 0;

controlnames  = [ynamesInRegression zvariablesToConsider2];
controlnames2 = [{'d_mn'} zvariablesToConsider2];

% Loop over y-variables
for j = daysToLookBack
    % Instrument variable
    x   = d_mn(ib, j);
    for jj = daysToLookBack
        
        % Change in news before/after
        y   = d_nn(ib, jj);     
        n   = size(y, 1);        
        tmp = XX{:,ynamesInRegression}(ia, :);
        z   = tmp(1:end, :);                                      
                    
        % Add NB target and path controls to other contol varibles
        cc = [z c];
                
        [B, FitInfo] = lasso(cc, y, 'CV', 5, 'PredictorNames', controlnames);        
        minMSEModel_firstStage1 = FitInfo.PredictorNames(B(:,FitInfo.Index1SE)~=0);    
        residuals   = y - cc*B;
        e2          = mean(residuals.^2);
        df          = sum(B ~= 0);
        bici        = n*log(e2) + log(n)*df;    
        [~, bici_idx] = min(bici);
        minMSEModel_firstStage1_bic = FitInfo.PredictorNames(B(:, bici_idx)~=0);            
        % Do lasso on x
        [B, FitInfo] = lasso(cc, x, 'CV', 5, 'PredictorNames', controlnames);
        minMSEModel_secondStage = FitInfo.PredictorNames(B(:,FitInfo.Index1SE)~=0);
        residuals   = x - cc*B;
        e2          = mean(residuals.^2);
        df          = sum(B ~= 0);
        bici        = n*log(e2) + log(n)*df;    
        [~, bici_idx] = min(bici);
        minMSEModel_secondStage_bic = FitInfo.PredictorNames(B(:, bici_idx)~=0);            
        % get union
        unionOfPredictors1      = union(minMSEModel_firstStage1,minMSEModel_secondStage);
        unionOfPredictors1_bic  = union(minMSEModel_firstStage1_bic,minMSEModel_secondStage_bic);        
        % Do OLS on chosen sets
        [~,~,ibb] = intersect(unionOfPredictors1, controlnames);
        mdl = fitlm([x cc(:, ibb)], y, 'Intercept', true, 'PredictorVars', [{'d_mn'} unionOfPredictors1]);
        doubleLassoResults{j, jj} = mdl;

        [~,~,ibb] = intersect(unionOfPredictors1_bic, controlnames);
        mdl = fitlm([x cc(:, ibb)], y, 'Intercept', true, 'PredictorVars', [{'d_mn'} unionOfPredictors1_bic]);
        doubleLassoResults_bic{j, jj} = mdl;        
                                         
        
        %% Do the same, but with s1 and s2 as potential explanatory variables        
        cc = [x c];
        
        [B, FitInfo] = lasso(cc, y, 'CV', 5, 'PredictorNames', controlnames2);
        minMSEModel_firstStage1 = FitInfo.PredictorNames(B(:,FitInfo.Index1SE)~=0);    
        residuals   = y - cc*B;
        e2          = mean(residuals.^2);
        df          = sum(B ~= 0);
        bici        = n*log(e2) + log(n)*df;    
        [~, bici_idx] = min(bici);
        minMSEModel_firstStage1_bic = FitInfo.PredictorNames(B(:, bici_idx)~=0);            
        
        % Do lasso on z1
        [B, FitInfo] = lasso(cc, z(:, 1), 'CV', 5, 'PredictorNames', controlnames2);        
        minMSEModel_secondStage = FitInfo.PredictorNames(B(:,FitInfo.Index1SE)~=0);
        residuals   = x - cc*B;
        e2          = mean(residuals.^2);
        df          = sum(B ~= 0);
        bici        = n*log(e2) + log(n)*df;    
        [~, bici_idx] = min(bici);
        minMSEModel_secondStage_bic = FitInfo.PredictorNames(B(:, bici_idx)~=0);            
        % get union
        unionOfPredictors1      = union(minMSEModel_firstStage1,minMSEModel_secondStage);
        unionOfPredictors1_bic  = union(minMSEModel_firstStage1_bic,minMSEModel_secondStage_bic);        
        % Do OLS on chosen sets
        [~,~,ibb] = intersect(unionOfPredictors1, controlnames2);
        mdl = fitlm([z(:, 1) cc(:, ibb)], y, 'Intercept', true, 'PredictorVars', [{'s1'} unionOfPredictors1]);
        doubleLassoResults_s1{j, jj} = mdl;

        [~,~,ibb] = intersect(unionOfPredictors1_bic, controlnames2);
        mdl = fitlm([z(:, 1) cc(:, ibb)], y, 'Intercept', true, 'PredictorVars', [{'s1'} unionOfPredictors1_bic]);
        doubleLassoResults_bic_s1{j, jj} = mdl;             
               
        % Do lasso on z2
        [B, FitInfo] = lasso(cc, z(:, 2), 'CV', 5, 'PredictorNames', controlnames2);
        minMSEModel_secondStage = FitInfo.PredictorNames(B(:,FitInfo.Index1SE)~=0);
        residuals   = x - cc*B;
        e2          = mean(residuals.^2);
        df          = sum(B ~= 0);
        bici        = n*log(e2) + log(n)*df;    
        [~, bici_idx] = min(bici);
        minMSEModel_secondStage_bic = FitInfo.PredictorNames(B(:, bici_idx)~=0);            
        % get union
        unionOfPredictors1      = union(minMSEModel_firstStage1,minMSEModel_secondStage);
        unionOfPredictors1_bic  = union(minMSEModel_firstStage1_bic,minMSEModel_secondStage_bic);        
        % Do OLS on chosen sets
        [~,~,ibb] = intersect(unionOfPredictors1, controlnames2);
        mdl = fitlm([z(:, 2) cc(:, ibb)], y, 'Intercept', true, 'PredictorVars', [{'s2'} unionOfPredictors1]);
        doubleLassoResults_s2{j, jj} = mdl;

        [~,~,ibb] = intersect(unionOfPredictors1_bic, controlnames2);
        mdl = fitlm([z(:, 2) cc(:, ibb)], y, 'Intercept', true, 'PredictorVars', [{'s2'} unionOfPredictors1_bic]);
        doubleLassoResults_bic_s2{j, jj} = mdl;                        
        
        
    end
end


%% save 
save( fullfile(savePath, 'beforeAfterRegression_surpriseSign.mat'), 'daysToLookBack', 'doubleLassoResults', 'doubleLassoResults_bic', 'ynamesInRegression', 'controlnames',...
        'doubleLassoResults_s1', 'doubleLassoResults_bic_s1', 'doubleLassoResults_s2', 'doubleLassoResults_bic_s2', 'controlnames2')         

