%% This script runs all the scripts needed to produce the main results 
%% presented in Figures 1 and 3a and 3b in the paper:
%% Saskia ter Ellen, Vegard H. Larsen, Leif Anders Thorsrud (2020), 
%% Narrative monetary policy surprises and the media, 
%% Journal of Money Credit and Banking.
%%
%% The sequence of processing is important. I.e., cell 1) has to be run 
%% before 2) etc. 
%% All data used should be placed in the folder .\data
%% All numerical output is saved to the folder .\results
%% All figures are saved to the folder .\figures
%% 
%% Note: Most of the data used in this paper are proprietary (see the 
%% readme.txt file). To load the exisiting results and produce the 
%% figures, only run cell 5) below. Running the script from cell 1) will 
%% potentially overwrite the existing results used to produce the figures
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% 1) Run this script to construct the factors
do_constructFactors

%% 2) Create the narrative surprise
do_constructNarrativeSurprise

%% 3) Produce the output needed for figure 3.a
do_narrative_conventional_regression

%% 4) Produce the output needed for figure 3.b
do_before_after_regression

%% 5) Construct plots of the results

% Fig 1
plot_factors
% Fig 3.a
plot_narrative_conventional_regression
% Fig 3.b
plot_before_after_regression