%% This script constructs output needed for figure 3.a in the paper
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

savePath    = '.\results';    
loadPath    = '.\data';

%% Names of data (in the control variable set) to include in the RHS (LHS) 
%% when doing the regressions
ynamesInRegression = {'Target', 'Path'};

zvariablesToConsider = {'CPI_0', 'CPI_1','CPI_2',...
                            'OGAP_0', 'OGAP_1','OGAP_2',...
                                'ECB_target', 'ECB_path'};
zvariablesToConsider2 = {'CPI_0', 'CPI_1','CPI_2',...
                            'OGAP_0', 'OGAP_1','OGAP_2',...
                                'KPR_0', 'KPR_1','KPR_2',...
                                    'ECB_target', 'ECB_path'};                        

%% Load controlVariables as a table
XX = readtable(fullfile(loadPath, 'controlData.csv'));

%% Empty output
[doubleLassoResults, doubleLassoResults_bic,...
    doubleLassoResults2, doubleLassoResults2_bic] = deal(cell(numel(daysToLookBack), 2));

%% Load surprises
results  = load(fullfile(savePath, 'narrativeSurpriseSign.mat'));
dn_mn    = results.d_mn;

%% Do the loop over window size and DS. 
for db = daysToLookBack

    %% Do double selection Lasso        
    zdata               = XX{:, zvariablesToConsider};        
    zdata2              = XX{:, zvariablesToConsider2};        
    zdata(isnan(zdata))     = 0;
    zdata2(isnan(zdata2))   = 0;

    [commonDates, ia, ib] = intersect(XX.Date, cellstr(char(results.eba_dates)));
    
    for i = 1 : numel(ynamesInRegression)    
    
        y1  = XX.(ynamesInRegression{i})(ia);        
        z    = (zdata(ia, :));        
        z2   = (zdata2(ia, :));        
        x    = dn_mn(ib, db);

        % Note, using only y1 here
        nanidx  = isnan(sum([y1 x z], 2));
        nanidx2 = isnan(sum([y1 x z2], 2));
        
        % Adjust y and zz 
        yy   = y1(nanidx == 0);
        zz   = z(nanidx == 0, :);        
        xx   = x(nanidx == 0);
        
        yy2   = y1(nanidx2 == 0);
        zz2   = z2(nanidx2 == 0, :);        
        xx2   = x(nanidx2 == 0);        

        lassoDates  = commonDates(nanidx == 0);
        lassoDates2 = commonDates(nanidx2 == 0);
        
        %% Do Double selection on first control variable set. (...copy paste...)
        n               = size(yy, 1);

        [B, FitInfo] = lasso(zz, yy, 'CV', 5, 'PredictorNames', zvariablesToConsider);
        minMSEModel_firstStage1 = FitInfo.PredictorNames(B(:,FitInfo.Index1SE)~=0);    
        residuals   = yy - zz*B;
        e2          = mean(residuals.^2);
        df          = sum(B ~= 0);
        bici        = n*log(e2) + log(n)*df;    
        [~, bici_idx] = min(bici);
        minMSEModel_firstStage1_bic = FitInfo.PredictorNames(B(:, bici_idx)~=0);            
        % Do lasso on x
        [B, FitInfo] = lasso(zz, xx, 'CV', 5, 'PredictorNames', zvariablesToConsider);
        minMSEModel_secondStage = FitInfo.PredictorNames(B(:,FitInfo.Index1SE)~=0);
        residuals   = xx - zz*B;
        e2          = mean(residuals.^2);
        df          = sum(B ~= 0);
        bici        = n*log(e2) + log(n)*df;    
        [~, bici_idx] = min(bici);
        minMSEModel_secondStage_bic = FitInfo.PredictorNames(B(:, bici_idx)~=0);            
        % get union
        unionOfPredictors1      = union(minMSEModel_firstStage1,minMSEModel_secondStage);
        unionOfPredictors1_bic  = union(minMSEModel_firstStage1_bic,minMSEModel_secondStage_bic);        
        % Do OLS on chosen sets
        [~,~,ibb] = intersect(unionOfPredictors1, zvariablesToConsider);
        mdl = fitlm([xx zz(:, ibb)], yy, 'Intercept', true, 'PredictorVars', [{'cosinediff'} unionOfPredictors1]);
        doubleLassoResults{db, i} = mdl;

        [~,~,ibb] = intersect(unionOfPredictors1_bic, zvariablesToConsider);
        mdl = fitlm([xx zz(:, ibb)], yy, 'Intercept', true, 'PredictorVars', [{'cosinediff'} unionOfPredictors1_bic]);
        doubleLassoResults_bic{db, i} = mdl;
        
        %% Do Double selection on second control variable set. 
        n               = size(yy2, 1);

        [B, FitInfo] = lasso(zz2, yy2, 'CV', 5, 'PredictorNames', zvariablesToConsider2);
        minMSEModel_firstStage1 = FitInfo.PredictorNames(B(:,FitInfo.Index1SE)~=0);    
        residuals   = yy2 - zz2*B;
        e2          = mean(residuals.^2);
        df          = sum(B ~= 0);
        bici        = n*log(e2) + log(n)*df;    
        [~, bici_idx] = min(bici);
        minMSEModel_firstStage1_bic = FitInfo.PredictorNames(B(:, bici_idx)~=0);            
        % Do lasso on x
        [B, FitInfo] = lasso(zz2, xx2, 'CV', 5, 'PredictorNames', zvariablesToConsider2);
        minMSEModel_secondStage = FitInfo.PredictorNames(B(:,FitInfo.Index1SE)~=0);
        residuals   = xx2 - zz2*B;
        e2          = mean(residuals.^2);
        df          = sum(B ~= 0);
        bici        = n*log(e2) + log(n)*df;    
        [~, bici_idx] = min(bici);
        minMSEModel_secondStage_bic = FitInfo.PredictorNames(B(:, bici_idx)~=0);            
        % get union
        unionOfPredictors1      = union(minMSEModel_firstStage1,minMSEModel_secondStage);
        unionOfPredictors1_bic  = union(minMSEModel_firstStage1_bic,minMSEModel_secondStage_bic);        
        % Do OLS on chosen sets
        [~,~,ibb] = intersect(unionOfPredictors1, zvariablesToConsider2);
        mdl = fitlm([xx2 zz2(:, ibb)], yy2, 'Intercept', true, 'PredictorVars', [{'cosinediff'} unionOfPredictors1]);
        doubleLassoResults2{db, i} = mdl;

        [~,~,ibb] = intersect(unionOfPredictors1_bic, zvariablesToConsider2);
        mdl = fitlm([xx2 zz2(:, ibb)], yy2, 'Intercept', true, 'PredictorVars', [{'cosinediff'} unionOfPredictors1_bic]);
        doubleLassoResults2_bic{db, i} = mdl;        
        
    end
    
end
%% Save the stuff 

save( fullfile(savePath, ['doubleLassoResults_surpriseSign.mat']), 'doubleLassoResults', 'doubleLassoResults_bic', 'lassoDates', 'ynamesInRegression',...
                            'doubleLassoResults2', 'doubleLassoResults2_bic', 'lassoDates2');

