%% This script produces figures similar to Fig. 3.b in the paper
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

savePath        = '.\figures';          
loadPath        = '.\results';

%% Laod results 
results = load(fullfile(loadPath, 'beforeAfterRegression_surpriseSign.mat'));

%% Extract main results

tstatNarrative  = arrayfun(@(x) x{1,1}.Coefficients.tStat(2), results.doubleLassoResults_bic(daysToLookBack, daysToLookBack));
N               = size(tstatNarrative, 1);
tstatNarrative_s1  = arrayfun(@(x) x{1,1}.Coefficients.tStat(2), results.doubleLassoResults_bic_s1(daysToLookBack, daysToLookBack));
tstatNarrative_s2  = arrayfun(@(x) x{1,1}.Coefficients.tStat(2), results.doubleLassoResults_bic_s2(daysToLookBack, daysToLookBack));

%%
X = daysToLookBack(1:10);
Y = daysToLookBack(1:5);

%%
fhh = figure;
sh = surf(Y, X, tstatNarrative_s1(X,Y,1),...
    'Facecolor', 'interp',...
    'FaceLighting', 'gouraud',...
    'Linestyle', ':');
hold on 
sh = surf(Y, X, tstatNarrative(X,Y,1),...
    'Facecolor', 'interp',...
    'FaceLighting', 'gouraud',...
    'Linestyle', ':');
%colormap(flipud(gray))
colormap(gray)
set(gca, 'FontSize', 8);
axis tight
set(gca, 'zlim', [-2.3 7.6632]);
view([-127.3000   24.6000])
xlab = xlabel('Periods forwards  ($w^{+}$)', 'HorizontalAlignment', 'right', 'fontSize', 10, 'FontName', 'Cambria','Rotation', -22, 'interpreter', 'latex', 'position', [1.6519 11 -2.5]);         
ylab = ylabel('Periods backwards  ($w^{-}$)', 'HorizontalAlignment', 'left', 'fontSize', 10, 'FontName', 'Cambria','Rotation', 14, 'interpreter', 'latex', 'position', [1.8 5.9977 -4.5]); 
zlabel('t-value', 'HorizontalAlignment', 'center', 'fontSize', 10, 'FontName', 'Cambria', 'interpreter', 'latex');        
ztick       = get(gca, 'ZTick');
ztickLabel  = get(gca, 'ZTicklabel');
hold on
xa = [1 max(Y);max(Y) max(Y);max(Y) 1;1 1]; % from-to. for each vertice, which is the different rows
ya = [1 1;1 max(X);max(X) max(X);max(X) 1]; % from-to. for each vertice, which is the different rows
criticalValues = abs(tinv([0.05]./2,inf));
za = [criticalValues criticalValues;criticalValues criticalValues;criticalValues criticalValues;criticalValues criticalValues];
fh  = fill3(xa,ya,za, [0 0 01], 'FaceAlpha', 0.5);
fh2 = fill3(xa,ya,-za, [0 0 01], 'FaceAlpha', 0.5);
text(3, 2, 4, '$m_{t}=f(n_{t})$', 'interpreter', 'latex', 'color', [0.3 0.3 0.3])
text(2, 1, 0.2, '$m_{t}=f(s_{t}^{T})$', 'interpreter', 'latex', 'color', [0 0 0])
set(gca, 'clim', [-1 6])
saveas(gcf, fullfile(savePath, 'beforeAfterRegression_bic_targetshocks_surpriseSign.png'))

%%

fhh = figure;
sh = surf(Y, X, tstatNarrative_s2(X,Y,1),...
    'Facecolor', 'interp',...
    'FaceLighting', 'gouraud',...
    'Linestyle', ':');
%'EdgeColor', 'none',...
hold on 
sh = surf(Y, X, tstatNarrative(X,Y,1),...
    'Facecolor', 'interp',...
    'FaceLighting', 'gouraud',...
    'Linestyle', ':');
%colormap(flipud(gray))
colormap(gray)
set(gca, 'FontSize', 8);
axis tight
set(gca, 'zlim', [-2.3 7.6632]);
view([-127.3000   24.6000])
%caxis([-0.3 1]) 
xlab = xlabel('Periods forwards  ($w^{+}$)', 'HorizontalAlignment', 'right', 'fontSize', 10, 'FontName', 'Cambria','Rotation', -22, 'interpreter', 'latex', 'position', [1.6519 11 -2.5]);         
ylab = ylabel('Periods backwards  ($w^{-}$)', 'HorizontalAlignment', 'left', 'fontSize', 10, 'FontName', 'Cambria','Rotation', 14, 'interpreter', 'latex', 'position', [1.8 5.9977 -4.5]); 
zlabel('t-value', 'HorizontalAlignment', 'center', 'fontSize', 10, 'FontName', 'Cambria', 'interpreter', 'latex');        
%camlight('headlight')
ztick       = get(gca, 'ZTick');
ztickLabel  = get(gca, 'ZTicklabel');
hold on
xa = [1 max(Y);max(Y) max(Y);max(Y) 1;1 1]; % from-to. for each vertice, which is the different rows
ya = [1 1;1 max(X);max(X) max(X);max(X) 1]; % from-to. for each vertice, which is the different rows
za = [criticalValues criticalValues;criticalValues criticalValues;criticalValues criticalValues;criticalValues criticalValues];
fh  = fill3(xa,ya,za, [0 0 01], 'FaceAlpha', 0.5);
fh2 = fill3(xa,ya,-za, [0 0 01], 'FaceAlpha', 0.5);
text(3, 2, 4, '$m_{t}=f(n_{t})$', 'interpreter', 'latex', 'color', [0.3 0.3 0.3])
text(2.5, 1, -1.65, '$m_{t}=f(s_{t}^{P})$', 'interpreter', 'latex', 'color', [0 0 0])
set(gca, 'clim', [-1 6])
saveas(gcf, fullfile(savePath, 'beforeAfterRegression_bic_pathshocks_surpriseSign.png'))


%%

