%% This script produces figures similar to Fig. 3.a in the paper
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

savePath        = '.\figures';          
loadPath        = '.\results';

%% Load the results

results = load(fullfile(loadPath, 'doubleLassoResults_surpriseSign.mat'));

%% 
steps               = 1;

%% Double selection results

criticalValues = tinv([0.1 0.05 0.01]./2,inf).*ones(numel(daysToLookBack), 3);
criticalValues = [criticalValues abs(criticalValues)];

tstatIndivid        = arrayfun(@(x) x{1,1}.Coefficients.tStat(2:end), results.doubleLassoResults, 'UniformOutput', false);
numberOfControls    = arrayfun(@(x) numel(x{1}), tstatIndivid) - 1; %itself and the constant not counted. 
tstatAll            = arrayfun(@(x) x{1,1}.Coefficients.tStat(2), results.doubleLassoResults);
r2a                 = arrayfun(@(x) x{1,1}.Rsquared.Adjusted, results.doubleLassoResults);
tstatIndivid        = tstatIndivid(daysToLookBack, :);
numberOfControls    = numberOfControls(daysToLookBack, :);
tstatAll            = tstatAll(daysToLookBack, :);
r2a                 = r2a(daysToLookBack, :);


fh = figure;
p1 = plot(daysToLookBack, tstatAll(:, 1), 'color', [0 0 0], 'linewidth', 2);
hold on
p2 = plot(daysToLookBack, tstatAll(:, 2), 'color', [0.5 0.5 0.5], 'linewidth', 2);
p3 = plot(daysToLookBack, criticalValues, 'color', [0 0 0], 'linewidth', 0.5, 'linestyle', ':');
lh = legend([p1 p2], {'$s_{t}^{T}$', '$s_{t}^{P}$'}, 'box', 'off', 'interpreter', 'latex', 'location', 'northwest');
text(daysToLookBack(1:steps:end), tstatAll((1:steps:end), 1)+0.3, num2str(r2a((1:steps:end),1), '%0.2f'))
text(daysToLookBack(1:steps:end), tstatAll((1:steps:end), 2)+0.3, num2str(r2a((1:steps:end),2), '%0.2f'), 'color', [0.5 0.5 0.5])
text(daysToLookBack(1:steps:end), tstatAll((1:steps:end), 1)-0.3, num2str(numberOfControls((1:steps:end),1), '%0.0f'))
text(daysToLookBack(1:steps:end), tstatAll((1:steps:end), 2)-0.3, num2str(numberOfControls((1:steps:end),2), '%0.0f'), 'color', [0.5 0.5 0.5])
text(daysToLookBack(5)-3, tstatAll(5, 1)+0.65, 'Adjusted $R^2$',  'interpreter', 'latex');
text(daysToLookBack(5)+1.5, tstatAll(5, 1)-0.5, 'Number of controls',  'interpreter', 'latex');
xlabel('Periods backwards ($w^{-}$)', 'HorizontalAlignment', 'center', 'fontSize', 10, 'FontName', 'Cambria', 'interpreter', 'latex');        
ylabel('t-value', 'HorizontalAlignment', 'center', 'fontSize', 10, 'FontName', 'Cambria', 'interpreter', 'latex');        
axis tight
set(gca, 'xtickLabelRotation', 45)
box off
saveas(gcf, fullfile(savePath, 'tstatCosineDoubleSelection_CV_surpriseSign.png'))

tstatIndivid        = arrayfun(@(x) x{1,1}.Coefficients.tStat(2:end), results.doubleLassoResults_bic, 'UniformOutput', false);
numberOfControls    = arrayfun(@(x) numel(x{1}), tstatIndivid) -1;
tstatAll            = arrayfun(@(x) x{1,1}.Coefficients.tStat(2), results.doubleLassoResults_bic);
r2a                 = arrayfun(@(x) x{1,1}.Rsquared.Adjusted, results.doubleLassoResults_bic);
tstatIndivid        = tstatIndivid(daysToLookBack, :);
numberOfControls    = numberOfControls(daysToLookBack, :);
tstatAll            = tstatAll(daysToLookBack, :);
r2a                 = r2a(daysToLookBack, :);

fh = figure;
p1 = plot(daysToLookBack, tstatAll(:, 1), 'color', [0 0 0], 'linewidth', 2);
hold on
p2 = plot(daysToLookBack, tstatAll(:, 2), 'color', [0.5 0.5 0.5], 'linewidth', 2);
p3 = plot(daysToLookBack, criticalValues, 'color', [0 0 0], 'linewidth', 0.5, 'linestyle', ':');
lh = legend([p1 p2], {'$s_{t}^{T}$', '$s_{t}^{P}$'}, 'box', 'off', 'interpreter', 'latex', 'location', 'northwest');
text(daysToLookBack(1:steps:end), tstatAll((1:steps:end), 1)+0.3, num2str(r2a((1:steps:end),1), '%0.2f'))
text(daysToLookBack(1:steps:end), tstatAll((1:steps:end), 2)+0.3, num2str(r2a((1:steps:end),2), '%0.2f'), 'color', [0.5 0.5 0.5])
text(daysToLookBack(1:steps:end), tstatAll((1:steps:end), 1)-0.3, num2str(numberOfControls((1:steps:end),1), '%0.0f'))
text(daysToLookBack(1:steps:end), tstatAll((1:steps:end), 2)-0.3, num2str(numberOfControls((1:steps:end),2), '%0.0f'), 'color', [0.5 0.5 0.5])
text(6, tstatAll(5, 1)+0.3, 'Adjusted $R^2$',  'interpreter', 'latex');
text(3.5, tstatAll(5, 1)-0.6, 'Number of controls',  'interpreter', 'latex');
xlabel('Periods backwards ($w^{-}$)', 'HorizontalAlignment', 'center', 'fontSize', 10, 'FontName', 'Cambria', 'interpreter', 'latex');        
ylabel('t-value', 'HorizontalAlignment', 'center', 'fontSize', 10, 'FontName', 'Cambria', 'interpreter', 'latex');        
axis tight
set(gca, 'xtickLabelRotation', 45)
box off
saveas(gcf, fullfile(savePath, 'tstatCosineDoubleSelection_BIC_surpriseSign.png'))



